fnss.netconfig.nodeconfig.get_stack — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »

# fnss.netconfig.nodeconfig.get_stack

`get_stack`(topology, node)

  Return the stack of a node, if any

  Parameters : | topology : Topology The topology node : any hashable type The ID of the node
  Returns : | stack : tuple (name, properties) A tuple of two values, where the first value is the name of the stack and the second value is the dictionary of properties of the stack.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- FNSS 0.3.2 documentation »
- API Reference »
- Functions »